@@ -77,7 +77,7 @@ static void R128DRIRefreshArea(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
    client. */
 static Bool R128InitVisualConfigs(ScreenPtr pScreen)
 {
-    ScrnInfoPtr       pScrn            = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr       pScrn            = xf86ScreenToScrn(pScreen);
     R128InfoPtr       info             = R128PTR(pScrn);
     int               numConfigs       = 0;
     __GLXvisualConfig *pConfigs        = NULL;
@@ -105,21 +105,21 @@ static Bool R128InitVisualConfigs(ScreenPtr pScreen)
 	if (R128_USE_DB)      numConfigs *= 2;
 
 	if (!(pConfigs
-	      = (__GLXvisualConfig*)xcalloc(sizeof(__GLXvisualConfig),
+	      = (__GLXvisualConfig*)calloc(sizeof(__GLXvisualConfig),
 					      numConfigs))) {
 	    return FALSE;
 	}
 	if (!(pR128Configs
-	      = (R128ConfigPrivPtr)xcalloc(sizeof(R128ConfigPrivRec),
+	      = (R128ConfigPrivPtr)calloc(sizeof(R128ConfigPrivRec),
 					     numConfigs))) {
-	    xfree(pConfigs);
+	    free(pConfigs);
 	    return FALSE;
 	}
 	if (!(pR128ConfigPtrs
-	      = (R128ConfigPrivPtr*)xcalloc(sizeof(R128ConfigPrivPtr),
+	      = (R128ConfigPrivPtr*)calloc(sizeof(R128ConfigPrivPtr),
 					      numConfigs))) {
-	    xfree(pConfigs);
-	    xfree(pR128Configs);
+	    free(pConfigs);
+	    free(pR128Configs);
 	    return FALSE;
 	}
 
@@ -188,21 +188,21 @@ static Bool R128InitVisualConfigs(ScreenPtr pScreen)
 	if (R128_USE_DB)      numConfigs *= 2;
 
 	if (!(pConfigs
-	      = (__GLXvisualConfig*)xcalloc(sizeof(__GLXvisualConfig),
+	      = (__GLXvisualConfig*)calloc(sizeof(__GLXvisualConfig),
 					      numConfigs))) {
 	    return FALSE;
 	}
 	if (!(pR128Configs
-	      = (R128ConfigPrivPtr)xcalloc(sizeof(R128ConfigPrivRec),
+	      = (R128ConfigPrivPtr)calloc(sizeof(R128ConfigPrivRec),
 					     numConfigs))) {
-	    xfree(pConfigs);
+	    free(pConfigs);
 	    return FALSE;
 	}
 	if (!(pR128ConfigPtrs
-	      = (R128ConfigPrivPtr*)xcalloc(sizeof(R128ConfigPrivPtr),
+	      = (R128ConfigPrivPtr*)calloc(sizeof(R128ConfigPrivPtr),
 					      numConfigs))) {
-	    xfree(pConfigs);
-	    xfree(pR128Configs);
+	    free(pConfigs);
+	    free(pR128Configs);
 	    return FALSE;
 	}
 
@@ -279,7 +279,7 @@ static Bool R128CreateContext(ScreenPtr pScreen, VisualPtr visual,
 			      drm_context_t hwContext, void *pVisualConfigPriv,
 			      DRIContextType contextStore)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     R128InfoPtr info = R128PTR(pScrn);
 
     info->drmCtx = hwContext;
@@ -301,7 +301,7 @@ static void R128DestroyContext(ScreenPtr pScreen, drm_context_t hwContext,
    can start/stop the engine. */
 static void R128EnterServer(ScreenPtr pScreen)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     R128InfoPtr info = R128PTR(pScrn);
 
     if (info->accel) info->accel->NeedToSync = TRUE;
@@ -315,7 +315,7 @@ static void R128EnterServer(ScreenPtr pScreen)
    can start/stop the engine. */
 static void R128LeaveServer(ScreenPtr pScreen)
 {
-    ScrnInfoPtr   pScrn     = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr   pScrn     = xf86ScreenToScrn(pScreen);
     R128InfoPtr   info      = R128PTR(pScrn);
     unsigned char *R128MMIO = info->MMIO;
 
@@ -356,7 +356,7 @@ static void R128DRIInitBuffers(WindowPtr pWin, RegionPtr prgn, CARD32 indx)
 {
     /* FIXME: This routine needs to have acceleration turned on */
     ScreenPtr   pScreen = pWin->drawable.pScreen;
-    ScrnInfoPtr pScrn   = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn   = xf86ScreenToScrn(pScreen);
     R128InfoPtr info    = R128PTR(pScrn);
     BoxPtr      pbox, pboxSave;
     int         nbox, nboxSave;
@@ -420,7 +420,7 @@ static void R128DRIMoveBuffers(WindowPtr pWin, DDXPointRec ptOldOrg,
 			       RegionPtr prgnSrc, CARD32 indx)
 {
     ScreenPtr   pScreen = pWin->drawable.pScreen;
-    ScrnInfoPtr pScrn   = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn   = xf86ScreenToScrn(pScreen);
     R128InfoPtr info   = R128PTR(pScrn);
 
     /* FIXME: This routine needs to have acceleration turned on */
@@ -905,7 +905,7 @@ static Bool R128DRIBufInit(R128InfoPtr info, ScreenPtr pScreen)
 
 static void R128DRIIrqInit(R128InfoPtr info, ScreenPtr pScreen)
 {
-   ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+   ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
 
    if (!info->irq) {
       info->irq = drmGetInterruptFromBusID(
@@ -969,7 +969,7 @@ static void R128DRICCEInit(ScrnInfoPtr pScrn)
    create the DRI data structures and initialize the DRI state. */
 Bool R128DRIScreenInit(ScreenPtr pScreen)
 {
-    ScrnInfoPtr   pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr   pScrn = xf86ScreenToScrn(pScreen);
     R128InfoPtr   info = R128PTR(pScrn);
     DRIInfoPtr    pDRIInfo;
     R128DRIPtr    pR128DRI;
@@ -1026,7 +1026,7 @@ Bool R128DRIScreenInit(ScreenPtr pScreen)
     if (xf86LoaderCheckSymbol("DRICreatePCIBusID")) {
 	pDRIInfo->busIdString = DRICreatePCIBusID(info->PciInfo);
     } else {
-	pDRIInfo->busIdString            = xalloc(64);
+	pDRIInfo->busIdString            = malloc(64);
 	sprintf(pDRIInfo->busIdString,
 		"PCI:%d:%d:%d",
 		PCI_DEV_BUS(info->PciInfo),
@@ -1065,7 +1065,7 @@ Bool R128DRIScreenInit(ScreenPtr pScreen)
     pDRIInfo->SAREASize = SAREA_MAX;
 #endif
 
-    if (!(pR128DRI = (R128DRIPtr)xcalloc(sizeof(R128DRIRec),1))) {
+    if (!(pR128DRI = (R128DRIPtr)calloc(sizeof(R128DRIRec),1))) {
 	DRIDestroyInfoRec(info->pDRIInfo);
 	info->pDRIInfo = NULL;
 	return FALSE;
@@ -1091,7 +1091,7 @@ Bool R128DRIScreenInit(ScreenPtr pScreen)
     if (!DRIScreenInit(pScreen, pDRIInfo, &info->drmFD)) {
 	xf86DrvMsg(pScreen->myNum, X_ERROR,
                    "[dri] DRIScreenInit failed.  Disabling DRI.\n");
-	xfree(pDRIInfo->devPrivate);
+	free(pDRIInfo->devPrivate);
 	pDRIInfo->devPrivate = NULL;
 	DRIDestroyInfoRec(pDRIInfo);
 	pDRIInfo = NULL;
@@ -1206,7 +1206,7 @@ Bool R128DRIScreenInit(ScreenPtr pScreen)
    initialization. */
 Bool R128DRIFinishScreenInit(ScreenPtr pScreen)
 {
-    ScrnInfoPtr      pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr      pScrn = xf86ScreenToScrn(pScreen);
     R128InfoPtr      info  = R128PTR(pScrn);
     R128SAREAPrivPtr pSAREAPriv;
     R128DRIPtr       pR128DRI;
@@ -1291,7 +1291,7 @@ Bool R128DRIFinishScreenInit(ScreenPtr pScreen)
    resources used by the DRI. */
 void R128DRICloseScreen(ScreenPtr pScreen)
 {
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr pScrn = xf86ScreenToScrn(pScreen);
     R128InfoPtr info = R128PTR(pScrn);
     drmR128Init drmInfo;
 
@@ -1352,18 +1352,18 @@ void R128DRICloseScreen(ScreenPtr pScreen)
 				/* De-allocate all DRI data structures */
     if (info->pDRIInfo) {
 	if (info->pDRIInfo->devPrivate) {
-	    xfree(info->pDRIInfo->devPrivate);
+	    free(info->pDRIInfo->devPrivate);
 	    info->pDRIInfo->devPrivate = NULL;
 	}
 	DRIDestroyInfoRec(info->pDRIInfo);
 	info->pDRIInfo = NULL;
     }
     if (info->pVisualConfigs) {
-	xfree(info->pVisualConfigs);
+	free(info->pVisualConfigs);
 	info->pVisualConfigs = NULL;
     }
     if (info->pVisualConfigsPriv) {
-	xfree(info->pVisualConfigsPriv);
+	free(info->pVisualConfigsPriv);
 	info->pVisualConfigsPriv = NULL;
     }
 }
@@ -1416,7 +1416,7 @@ static void R128DRIRefreshArea(ScrnInfoPtr pScrn, int num, BoxPtr pbox)
 
 static void R128EnablePageFlip(ScreenPtr pScreen)
 {
-    ScrnInfoPtr         pScrn      = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr         pScrn      = xf86ScreenToScrn(pScreen);
     R128InfoPtr         info       = R128PTR(pScrn);
     R128SAREAPrivPtr    pSAREAPriv = DRIGetSAREAPrivate(pScreen);
 
@@ -1462,7 +1462,7 @@ static void R128DRITransitionMultiToSingle3d(ScreenPtr pScreen)
 
 static void R128DRITransitionTo3d(ScreenPtr pScreen)
 {
-    ScrnInfoPtr    pScrn = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr    pScrn = xf86ScreenToScrn(pScreen);
     R128InfoPtr    info  = R128PTR(pScrn);
 
     R128EnablePageFlip(pScreen);
@@ -1475,7 +1475,7 @@ static void R128DRITransitionTo3d(ScreenPtr pScreen)
 
 static void R128DRITransitionTo2d(ScreenPtr pScreen)
 {
-    ScrnInfoPtr         pScrn      = xf86Screens[pScreen->myNum];
+    ScrnInfoPtr         pScrn      = xf86ScreenToScrn(pScreen);
     R128InfoPtr         info       = R128PTR(pScrn);
     R128SAREAPrivPtr    pSAREAPriv = DRIGetSAREAPrivate(pScreen);
 
